New to Game Theory and/or Python
================================

This section contains a variety of tutorials that should help get you started
with the Axelrod library.

Contents:

.. toctree::
   :maxdepth: 2

   installation.rst
   match.rst
   tournament.rst
   summarising_tournaments.rst
   interactions.rst
   visualising_results.rst
   moran.rst
   human_interaction.rst
